﻿// <auto-generated />
// ------------------------------------------------------------------------------
// <copyright file="XamlTypeInfoProvider.cs" company="skumaronline.com">
//    Copyright (C) 2012 Suresh Kumar T.  All rights reserved.
// </copyright>
// ------------------------------------------------------------------------------

namespace StoreAppLib.MetaData
{
    using System;
    using System.Collections.Generic;
    using Windows.UI.Xaml.Markup;

    /// <summary>
    /// XAML type provider class
    /// </summary>
    [System.CodeDom.Compiler.GeneratedCodeAttribute("Microsoft.Windows.UI.Xaml.Build.Tasks", "4.0.0.0")]
    [System.Diagnostics.DebuggerNonUserCodeAttribute]
    public sealed class XamlTypeInfoProvider
    {
        /// <summary>
        /// Variable to hold the singleton instance of this class.
        /// </summary>
        private static readonly XamlTypeInfoProvider SingltonInstance = new XamlTypeInfoProvider();

        /// <summary>
        /// Variable to hold the XMAL types.
        /// </summary>
        private Dictionary<string, IXamlType> xamlTypes;

        /// <summary>
        /// Variable to hold XAML members
        /// </summary>
        private Dictionary<string, IXamlMember> xamlMembers;

        /// <summary>
        /// Variable to hold standard name mapping
        /// </summary>
        private Dictionary<Type, string> xamlTypeToStandardName;
               
        /// <summary>
        /// Prevents a default instance of the <see cref="XamlTypeInfoProvider"/> class from being created"
        /// </summary>
        private XamlTypeInfoProvider()
        {
            this.xamlTypes = new Dictionary<string, IXamlType>();
            this.xamlMembers = new Dictionary<string, IXamlMember>();
            this.xamlTypeToStandardName = new Dictionary<Type, string>();
        }

        /// <summary>
        /// Gets the singleton instance.
        /// </summary>
        /// <value>
        /// The singleton instance.
        /// </value>
        public static XamlTypeInfoProvider Instance
        {
            get
            {
                return XamlTypeInfoProvider.SingltonInstance;
            }
        }

        /// <summary>
        /// Retrieve XAML type from full name
        /// </summary>
        /// <param name="fullName">The type full name</param>
        /// <returns>The XAML type</returns>
        public IXamlType GetXamlTypeByName(string fullName)
        {
            if (string.IsNullOrWhiteSpace(fullName))
            {
                return null;
            }

            IXamlType xamlType;

            if (this.xamlTypes.TryGetValue(fullName, out xamlType))
            {
                return xamlType;
            }

            xamlType = this.CreateXamlType(fullName);

            if (xamlType != null)
            {
                this.xamlTypes.Add(fullName, xamlType);
            }

            return xamlType;
        }

        /// <summary>
        /// Retrieve XAML type from type
        /// </summary>
        /// <param name="type">The type</param>
        /// <returns>The XAML type</returns>
        public IXamlType GetXamlTypeByType(Type type)
        {
            string standardName;
            IXamlType xamlType = null;
            if (this.xamlTypeToStandardName.TryGetValue(type, out standardName))
            {
                xamlType = this.GetXamlTypeByName(standardName);
            }
            else
            {
                xamlType = this.GetXamlTypeByName(type.FullName);
            }

            return xamlType; 
        }

        /// <summary>
        /// Get XAML member by long name
        /// </summary>
        /// <param name="longMemberName">The long name</param>
        /// <returns>XAML member</returns>
        public IXamlMember GetMemberByLongName(string longMemberName)
        {
            if (System.String.IsNullOrEmpty(longMemberName))
            {
                return null;
            }
            
            IXamlMember xamlMember;
            
            if (this.xamlMembers.TryGetValue(longMemberName, out xamlMember))
            {
                return xamlMember;
            }

            xamlMember = this.CreateXamlMember(longMemberName);

            if (xamlMember != null)
            {
                this.xamlMembers.Add(longMemberName, xamlMember);
            }

            return xamlMember;
        }

        /// <summary>
        /// Add type to standard name mapping
        /// </summary>
        /// <param name="type">The type</param>
        /// <param name="standardName">The standard name</param>
        private void AddToMapOfTypeToStandardName(Type type, string standardName)
        {
            if (!this.xamlTypeToStandardName.ContainsKey(type))
            {
                this.xamlTypeToStandardName.Add(type, standardName);
            }
        }

        #region Contain auto generated code copied from RnD project

        /// <summary>
        /// Gets XAML type
        /// </summary>
        /// <param name="typeName">The type name</param>
        /// <returns>The XAML type</returns>
        private IXamlType CreateXamlType(string typeName)
        {
            XamlSystemBaseType xamlType = null;
            XamlUserType userType = null;

            switch (typeName)
            {

                case "Windows.UI.Xaml.Controls.ItemsControl":
                    xamlType = new global::StoreAppLib.MetaData.XamlSystemBaseType(typeName, typeof(global::Windows.UI.Xaml.Controls.ItemsControl));
                    break;

                case "Boolean":
                    xamlType = new global::StoreAppLib.MetaData.XamlSystemBaseType(typeName, typeof(global::System.Boolean));
                    break;

                case "Windows.UI.Xaml.Controls.UserControl":
                    xamlType = new global::StoreAppLib.MetaData.XamlSystemBaseType(typeName, typeof(global::Windows.UI.Xaml.Controls.UserControl));
                    break;

                case "Object":
                    xamlType = new global::StoreAppLib.MetaData.XamlSystemBaseType(typeName, typeof(global::System.Object));
                    break;

                case "String":
                    xamlType = new global::StoreAppLib.MetaData.XamlSystemBaseType(typeName, typeof(global::System.String));
                    break;

                case "Windows.UI.Xaml.Media.Brush":
                    xamlType = new global::StoreAppLib.MetaData.XamlSystemBaseType(typeName, typeof(global::Windows.UI.Xaml.Media.Brush));
                    break;

                case "Double":
                    xamlType = new global::StoreAppLib.MetaData.XamlSystemBaseType(typeName, typeof(global::System.Double));
                    break;

                case "Windows.UI.Xaml.Shapes.Path":
                    xamlType = new global::StoreAppLib.MetaData.XamlSystemBaseType(typeName, typeof(global::Windows.UI.Xaml.Shapes.Path));
                    break;

                case "Windows.UI.Xaml.DependencyObject":
                    xamlType = new global::StoreAppLib.MetaData.XamlSystemBaseType(typeName, typeof(global::Windows.UI.Xaml.DependencyObject));
                    break;



                case "StoreAppLib.Graph.PieItemsControl":
                    userType = new global::StoreAppLib.MetaData.XamlUserType(this, typeName, typeof(global::StoreAppLib.Graph.PieItemsControl), GetXamlTypeByName("Windows.UI.Xaml.Controls.ItemsControl"));
                    userType.Activator = Activate_0_PieItemsControl;
                    userType.AddMemberName("EnableTapEffect");
                    AddToMapOfTypeToStandardName(typeof(global::System.Boolean),
                                                       "Boolean");
                    xamlType = userType;
                    break;

                case "StoreAppLib.Graph.Pie":
                    userType = new global::StoreAppLib.MetaData.XamlUserType(this, typeName, typeof(global::StoreAppLib.Graph.Pie), GetXamlTypeByName("Windows.UI.Xaml.Controls.UserControl"));
                    userType.Activator = Activate_1_Pie;
                    userType.AddMemberName("EnableTapEffect");
                    AddToMapOfTypeToStandardName(typeof(global::System.Boolean),
                                                       "Boolean");
                    userType.AddMemberName("ItemsSource");
                    AddToMapOfTypeToStandardName(typeof(global::System.Object),
                                                       "Object");
                    userType.AddMemberName("SeriesColumnName");
                    AddToMapOfTypeToStandardName(typeof(global::System.String),
                                                       "String");
                    userType.AddMemberName("SeriesColorColumnName");
                    AddToMapOfTypeToStandardName(typeof(global::System.String),
                                                       "String");
                    userType.AddMemberName("Stroke");
                    userType.AddMemberName("StrokeThickness");
                    AddToMapOfTypeToStandardName(typeof(global::System.Double),
                                                       "Double");
                    userType.AddMemberName("ChartItemCommand");
                    xamlType = userType;
                    break;

                case "System.Windows.Input.ICommand":
                    userType = new global::StoreAppLib.MetaData.XamlUserType(this, typeName, typeof(global::System.Windows.Input.ICommand), null);
                    xamlType = userType;
                    break;

                case "StoreAppLib.Graph.Arc":
                    userType = new global::StoreAppLib.MetaData.XamlUserType(this, typeName, typeof(global::StoreAppLib.Graph.Arc), GetXamlTypeByName("Windows.UI.Xaml.Shapes.Path"));
                    userType.Activator = Activate_3_Arc;
                    userType.AddMemberName("TapCommand");
                    userType.AddMemberName("StartAngle");
                    AddToMapOfTypeToStandardName(typeof(global::System.Double),
                                                       "Double");
                    userType.AddMemberName("EndAngle");
                    AddToMapOfTypeToStandardName(typeof(global::System.Double),
                                                       "Double");
                    xamlType = userType;
                    break;

                case "StoreAppLib.Animations.TapEffect":
                    userType = new global::StoreAppLib.MetaData.XamlUserType(this, typeName, typeof(global::StoreAppLib.Animations.TapEffect), GetXamlTypeByName("Windows.UI.Xaml.DependencyObject"));
                    userType.Activator = Activate_4_TapEffect;
                    userType.AddMemberName("Enabled");
                    AddToMapOfTypeToStandardName(typeof(global::System.Boolean),
                                                       "Boolean");
                    xamlType = userType;
                    break;

            }

            return xamlType;
        }

        /// <summary>
        /// Creates XAML member from long member name
        /// </summary>
        /// <param name="longMemberName">Long member name</param>
        /// <returns>The XAML member </returns>
        private IXamlMember CreateXamlMember(string longMemberName)
        {
            XamlMember xamlMember = null;
            XamlUserType userType;

            switch (longMemberName)
            {
                case "StoreAppLib.Graph.PieItemsControl.EnableTapEffect":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.PieItemsControl");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "EnableTapEffect", "Boolean");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_0_PieItemsControl_EnableTapEffect;
                    xamlMember.Setter = set_0_PieItemsControl_EnableTapEffect;
                    break;
                case "StoreAppLib.Graph.Pie.EnableTapEffect":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Pie");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "EnableTapEffect", "Boolean");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_1_Pie_EnableTapEffect;
                    xamlMember.Setter = set_1_Pie_EnableTapEffect;
                    break;
                case "StoreAppLib.Graph.Pie.ItemsSource":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Pie");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "ItemsSource", "Object");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_2_Pie_ItemsSource;
                    xamlMember.Setter = set_2_Pie_ItemsSource;
                    break;
                case "StoreAppLib.Graph.Pie.SeriesColumnName":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Pie");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "SeriesColumnName", "String");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_3_Pie_SeriesColumnName;
                    xamlMember.Setter = set_3_Pie_SeriesColumnName;
                    break;
                case "StoreAppLib.Graph.Pie.SeriesColorColumnName":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Pie");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "SeriesColorColumnName", "String");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_4_Pie_SeriesColorColumnName;
                    xamlMember.Setter = set_4_Pie_SeriesColorColumnName;
                    break;
                case "StoreAppLib.Graph.Pie.Stroke":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Pie");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "Stroke", "Windows.UI.Xaml.Media.Brush");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_5_Pie_Stroke;
                    xamlMember.Setter = set_5_Pie_Stroke;
                    break;
                case "StoreAppLib.Graph.Pie.StrokeThickness":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Pie");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "StrokeThickness", "Double");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_6_Pie_StrokeThickness;
                    xamlMember.Setter = set_6_Pie_StrokeThickness;
                    break;
                case "StoreAppLib.Graph.Pie.ChartItemCommand":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Pie");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "ChartItemCommand", "System.Windows.Input.ICommand");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_7_Pie_ChartItemCommand;
                    xamlMember.Setter = set_7_Pie_ChartItemCommand;
                    break;
                case "StoreAppLib.Graph.Arc.TapCommand":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Arc");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "TapCommand", "System.Windows.Input.ICommand");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_8_Arc_TapCommand;
                    xamlMember.Setter = set_8_Arc_TapCommand;
                    break;
                case "StoreAppLib.Graph.Arc.StartAngle":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Arc");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "StartAngle", "Double");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_9_Arc_StartAngle;
                    xamlMember.Setter = set_9_Arc_StartAngle;
                    break;
                case "StoreAppLib.Graph.Arc.EndAngle":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Graph.Arc");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "EndAngle", "Double");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.Getter = get_10_Arc_EndAngle;
                    xamlMember.Setter = set_10_Arc_EndAngle;
                    break;
                case "StoreAppLib.Animations.TapEffect.Enabled":
                    userType = (global::StoreAppLib.MetaData.XamlUserType)GetXamlTypeByName("StoreAppLib.Animations.TapEffect");
                    xamlMember = new global::StoreAppLib.MetaData.XamlMember(this, "Enabled", "Boolean");
                    xamlMember.SetTargetTypeName("Windows.UI.Xaml.DependencyObject");
                    xamlMember.SetIsDependencyProperty();
                    xamlMember.SetIsAttachable();
                    xamlMember.Getter = get_11_TapEffect_Enabled;
                    xamlMember.Setter = set_11_TapEffect_Enabled;
                    break;
            }

            return xamlMember;
        }

        private object Activate_0_PieItemsControl() { return new global::StoreAppLib.Graph.PieItemsControl(); }

        private object Activate_1_Pie() { return new global::StoreAppLib.Graph.Pie(); }

        private object Activate_3_Arc() { return new global::StoreAppLib.Graph.Arc(); }

        private object Activate_4_TapEffect() { return new global::StoreAppLib.Animations.TapEffect(); }

        private object get_0_PieItemsControl_EnableTapEffect(object instance)
        {
            var that = (global::StoreAppLib.Graph.PieItemsControl)instance;
            return that.EnableTapEffect;
        }
        private void set_0_PieItemsControl_EnableTapEffect(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.PieItemsControl)instance;
            that.EnableTapEffect = (global::System.Boolean)Value;
        }
        private object get_1_Pie_EnableTapEffect(object instance)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            return that.EnableTapEffect;
        }
        private void set_1_Pie_EnableTapEffect(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            that.EnableTapEffect = (global::System.Boolean)Value;
        }
        private object get_2_Pie_ItemsSource(object instance)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            return that.ItemsSource;
        }
        private void set_2_Pie_ItemsSource(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            that.ItemsSource = (global::System.Object)Value;
        }
        private object get_3_Pie_SeriesColumnName(object instance)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            return that.SeriesColumnName;
        }
        private void set_3_Pie_SeriesColumnName(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            that.SeriesColumnName = (global::System.String)Value;
        }
        private object get_4_Pie_SeriesColorColumnName(object instance)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            return that.SeriesColorColumnName;
        }
        private void set_4_Pie_SeriesColorColumnName(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            that.SeriesColorColumnName = (global::System.String)Value;
        }
        private object get_5_Pie_Stroke(object instance)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            return that.Stroke;
        }
        private void set_5_Pie_Stroke(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            that.Stroke = (global::Windows.UI.Xaml.Media.Brush)Value;
        }
        private object get_6_Pie_StrokeThickness(object instance)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            return that.StrokeThickness;
        }
        private void set_6_Pie_StrokeThickness(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            that.StrokeThickness = (global::System.Double)Value;
        }
        private object get_7_Pie_ChartItemCommand(object instance)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            return that.ChartItemCommand;
        }
        private void set_7_Pie_ChartItemCommand(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Pie)instance;
            that.ChartItemCommand = (global::System.Windows.Input.ICommand)Value;
        }
        private object get_8_Arc_TapCommand(object instance)
        {
            var that = (global::StoreAppLib.Graph.Arc)instance;
            return that.TapCommand;
        }
        private void set_8_Arc_TapCommand(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Arc)instance;
            that.TapCommand = (global::System.Windows.Input.ICommand)Value;
        }
        private object get_9_Arc_StartAngle(object instance)
        {
            var that = (global::StoreAppLib.Graph.Arc)instance;
            return that.StartAngle;
        }
        private void set_9_Arc_StartAngle(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Arc)instance;
            that.StartAngle = (global::System.Double)Value;
        }
        private object get_10_Arc_EndAngle(object instance)
        {
            var that = (global::StoreAppLib.Graph.Arc)instance;
            return that.EndAngle;
        }
        private void set_10_Arc_EndAngle(object instance, object Value)
        {
            var that = (global::StoreAppLib.Graph.Arc)instance;
            that.EndAngle = (global::System.Double)Value;
        }
        private object get_11_TapEffect_Enabled(object instance)
        {
            return global::StoreAppLib.Animations.TapEffect.GetEnabled((global::Windows.UI.Xaml.DependencyObject)instance);
        }
        private void set_11_TapEffect_Enabled(object instance, object Value)
        {
            global::StoreAppLib.Animations.TapEffect.SetEnabled((global::Windows.UI.Xaml.DependencyObject)instance, (System.Boolean)Value);
        }

        #endregion
    }
}
