﻿// ------------------------------------------------------------------------------
// <copyright file="App.xaml.cs" company="skumaronline.com">
//    Copyright (C) 2012 Suresh Kumar T.  All rights reserved.
// </copyright>
// ------------------------------------------------------------------------------

namespace StoreAppLibDemo
{
    using System;
    using StoreAppLib.Controls;
    using StoreAppLibDemo.Examples.Settings;
    using Windows.ApplicationModel;
    using Windows.ApplicationModel.Activation;
    using Windows.UI.Popups;
    using Windows.UI.Xaml;
    using Windows.UI.Xaml.Controls;
    using Windows.UI.Xaml.Media;
    using Windows.UI;
    using StoreAppLibDemo.Examples.Controls;
    using StoreAppLibDemo.Examples.Animations;

    /// <summary>
    /// Provides application-specific behavior to supplement the default Application class.
    /// </summary>
    public sealed partial class App : Application
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="App"/> class"
        /// Initializes the singleton application object.  This is the first line of authored code
        /// executed, and as such is the logical equivalent of main() or WinMain().
        /// </summary>
        public App()
        {
            this.InitializeComponent();
            this.Suspending += this.OnSuspending;
            
            PageHeaderTextBlock.AddMenu(new GlobalNavigationMenuItem() { Label = "DatePicker", Page = typeof(DatePickerPage) });
            PageHeaderTextBlock.AddMenu(new GlobalNavigationMenuItem() { Label = "Page Header", Page = typeof(PageHeaderPage) });
            PageHeaderTextBlock.AddMenu(new GlobalNavigationMenuItem() { Label = "App Bar Button", Page = typeof(AppBarButtonPage) });
            PageHeaderTextBlock.AddMenu(new MenuSeparator());
            PageHeaderTextBlock.AddMenu(new GlobalNavigationMenuItem() { Label = "Tap Effect", Page = typeof(TapEffectPage) });

            PageHeaderTextBlock.MenuPointerOverBackground = new SolidColorBrush(Colors.WhiteSmoke);
            PageHeaderTextBlock.MenuPressedBackground = new SolidColorBrush(Colors.Wheat);
            PageHeaderTextBlock.MenuSeparatorColor = new SolidColorBrush(Colors.LightBlue);
            PageHeaderTextBlock.MenuSeparatorThickness = 2;
            PageHeaderTextBlock.MenuBackground = new SolidColorBrush(Colors.White);
            PageHeaderTextBlock.MenuForeground = new SolidColorBrush(Colors.DarkBlue);
            PageHeaderTextBlock.MenuBorderColor = new SolidColorBrush(Colors.LightBlue);
            PageHeaderTextBlock.MenuBorderThickness = 2;  
        }

        /// <summary>
        /// Invoked when the application is launched normally by the end user.  Other entry points
        /// will be used when the application is launched to open a specific file, to display
        /// search results, and so forth.
        /// </summary>
        /// <param name="args">Details about the launch request and process.</param>
        protected override void OnLaunched(LaunchActivatedEventArgs args)
        {
            Frame rootFrame = Window.Current.Content as Frame;

            // Do not repeat app initialization when the Window already has content,
            // just ensure that the window is active
            if (rootFrame == null)
            {
                // Create a Frame to act as the navigation context and navigate to the first page
                rootFrame = new Frame();

                if (args.PreviousExecutionState == ApplicationExecutionState.Terminated)
                {
                    ////TODO: Load state from previously suspended application
                }

                // Place the frame in the current Window
                Window.Current.Content = rootFrame;
            }

            if (rootFrame.Content == null)
            {
                // When the navigation stack isn't restored navigate to the first page,
                // configuring the new page by passing required information as a navigation
                // parameter
                if (!rootFrame.Navigate(typeof(MainPage), args.Arguments))
                {
                    throw new Exception("Failed to create initial page");
                }
            }

            // Ensure the current window is active
            Window.Current.Activate();

            //// Add a charm setting 
            CharmSetting.AddFlyout("About StoreAppLib", typeof(AboutSettingControl));

            //// Add a charm setting with custom call back
            CharmSetting.AddFlyout("About", "Custom Event Handler", new UICommandInvokedHandler(this.OnSettingCommandSelect));
        }

        /// <summary>
        /// Handle setting command directly
        /// </summary>
        /// <param name="command">The command</param>
        private void OnSettingCommandSelect(Windows.UI.Popups.IUICommand command)
        {
            CharmSettingFlyout flyout = new CharmSettingFlyout(new AboutSettingControl(), StoreAppLib.CharmSettingAnimation.Content);
            flyout.Open();
        }

        /// <summary>
        /// Invoked when application execution is being suspended.  Application state is saved
        /// without knowing whether the application will be terminated or resumed with the contents
        /// of memory still intact.
        /// </summary>
        /// <param name="sender">The source of the suspend request.</param>
        /// <param name="e">Details about the suspend request.</param>
        private void OnSuspending(object sender, SuspendingEventArgs e)
        {
            var deferral = e.SuspendingOperation.GetDeferral();

            ////TODO: Save application state and stop any background activity

            deferral.Complete();
        }
    }
}
